# pytest-jasmine
Run jasmine tests from pytest with selenium and report the results


Usage
```
From pytest_jasmine import Jasmine

jasmine = Jasmine('path/to/spec.html')
```

Invocation
```
pytest --with-jasmine
```
